==> v3.4.9.tar.gz: bookmarks/l10n/hu.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Könyvjelzők",
    "No file provided for import" : "Nincs fájl megadva importáláshoz",
    "Unsupported file type for import" : "Nem támogatott fájltípus az importáláshoz",
    "A Bookmark manager for Nextcloud" : "Könyvjelző kezelő Nextcloud-hoz",
    "Select bookmark" : "Válasszon könyvjelzőt",
    "Details" : "Részletek",
    "Rename" : "Átnevezés",
    "Move" : "Áthelyezés",
    "Delete" : "Törlés",
    "Select one or more tags" : "Válasszon egy vagy több címkét",
    "New" : "Új",
    "New folder" : "Új mappa",
    "Grid view" : "Rács nézet",
    "List view" : "Lista nézet",
    "Move selection" : "Kiválasztás áthelyezése",
    "Delete selection" : "Kiválasztás törlése",
    "Select all" : "Összes kijelölése",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["%n könyvjelző kiválasztva","%n könyvjelző kiválasztva"],
    "Enter a link" : "Adjon meg egy hivatkozást",
    "Enter folder title" : "Adja meg a mappa nevét",
    "Root folder" : "Gyökérmappa",
    "Submit" : "Beküldés",
    "Cancel" : "Mégse",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["%n mappa és néhány könyvjelző áthelyezése","%n mappa és néhány könyvjelző áthelyezése"],
    "_Moving %n folder_::_Moving %n folders_" : ["%n mappa áthelyezése","%n mappa áthelyezése"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["%n könyvjelző áthelyezése","%n könyvjelző áthelyezése"],
    "All bookmarks" : "Minden könyvjelző",
    "Recent" : "Friss",
    "Untagged" : "Nem cimkézett",
    "No bookmarks here" : "Itt nincsenek könyvjelzők",
    "Add a bookmark" : "Könyvjelző hozzáadása",
    "Import" : "Import",
    "Export" : "Exportálás",
    "Sorting" : "Rendezés",
    "Recently added" : "Utoljára hozzáadva",
    "Alphabetically" : "Betűrendben",
    "Most visited" : "Legtöbbet látogatva",
    "Last modified" : "Utoljára módosítva",
    "Client apps" : "Kliensalkalmazások",
    "Bookmarklet" : "Bookmarklet",
    "Add to {instanceName}" : "Hozzáadás ehhez: {instanceName}",
    "Clear data" : "Adatok törlése",
    "Delete all bookmarks" : "Összes könyvjelzők törlése",
    "Do you really want to delete all your bookmarks?" : "Biztos, hogy törli az összes könyvjelzőt?",
    "Title" : "Cím",
    "Link" : "Hivatkozás",
    "Creation date" : "Létrehozás dátuma",
    "Tags" : "Cimkék",
    "Attachments" : "Mellékletek",
    "Notes" : "Jegyzetek",
    "Owner" : "Tulajdonos",
    "Sharing" : "Megosztás",
    "Share link" : "Hivatkozás megosztása",
    "Copy link" : "Hivatkozás másolása",
    "Allow editing" : "Szerkesztés engedélyezése",
    "Remove share" : "Megosztás eltávolítása",
    "Link copied" : "Hivatkozás másolva",
    "Select" : "Kijelölés",
    "Previews" : "Előnézetek",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Ingyenesen regisztrálhat a screenly.com weboldalon, vagy beállíthatja a saját kiszolgálóját.",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API-kulcs",
    "Privacy" : "Adatvédelem",
    "Performance" : "Teljesítmény",
    "Failed to load settings" : "A beállítások betöltése sikertelen",
    "Failed to save settings" : "A beállítások mentése sikertelen",
    "This URL is already bookmarked! Overwrite?" : "Ez a cím már jegyezve van. Felülírod?",
    "Enter bookmark title" : "Adja meg a könyvjelző címét",
    "Enter bookmark URL" : "Adja meg a könyvjelző URL-ét",
    "Folder" : "Mappa",
    "Save" : "Mentés",
    "Failed to find existing bookmark" : "A létező könyvjelző keresése sikertelen",
    "Failed to create bookmark" : "Könyvjelző létrehozása sikertelen",
    "Failed to save bookmark" : "Könyvjelző mentése sikertelen",
    "Failed to move bookmark" : "Könyvjelző áthelyezése sikertelen",
    "Failed to delete bookmark" : "Könyvjelző törlése sikertelen",
    "Failed to load tags" : "Könyvjelző címkéinek betöltése sikertelen",
    "Failed to load folders" : "Mappák betöltése sikertelen",
    "Failed to delete folder" : "Mappa törlése sikertelen",
    "Failed to create folder" : "Mappa létrehozása sikertelen",
    "Failed to fetch bookmarks." : "Könyvjelzők lekérése sikertelen.",
    "Failed to change setting" : "Beállítások módosítása sikertelen",
    "Bookmarks feed" : "Könyvjelzők folyam"
},
"nplurals=2; plural=(n != 1);");

==> v4.1.0.tar.gz: bookmarks/l10n/hu.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Könyvjelzők",
    "No file provided for import" : "Nincs fájl megadva importáláshoz",
    "Unsupported file type for import" : "Nem támogatott fájltípus az importáláshoz",
    "Recent Bookmarks" : "Legújabb könyvjelzők",
    "A Bookmark manager for Nextcloud" : "Könyvjelző kezelő Nextcloud-hoz",
    "Select bookmark" : "Válasszon könyvjelzőt",
    "Details" : "Részletek",
    "Rename" : "Átnevezés",
    "Move" : "Áthelyezés",
    "Delete" : "Törlés",
    "Select one or more tags" : "Válasszon egy vagy több címkét",
    "New" : "Új",
    "New folder" : "Új mappa",
    "Grid view" : "Rács nézet",
    "List view" : "Lista nézet",
    "Move selection" : "Kiválasztás áthelyezése",
    "Delete selection" : "Kiválasztás törlése",
    "Select all" : "Összes kijelölése",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["%n könyvjelző kiválasztva","%n könyvjelző kiválasztva"],
    "Enter a link" : "Adjon meg egy hivatkozást",
    "Enter folder title" : "Adja meg a mappa nevét",
    "Root folder" : "Gyökérmappa",
    "Submit" : "Beküldés",
    "Cancel" : "Mégse",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["%n mappa és néhány könyvjelző áthelyezése","%n mappa és néhány könyvjelző áthelyezése"],
    "_Moving %n folder_::_Moving %n folders_" : ["%n mappa áthelyezése","%n mappa áthelyezése"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["%n könyvjelző áthelyezése","%n könyvjelző áthelyezése"],
    "All bookmarks" : "Minden könyvjelző",
    "Recent" : "Friss",
    "Untagged" : "Nem cimkézett",
    "No bookmarks here" : "Itt nincsenek könyvjelzők",
    "Add a bookmark" : "Könyvjelző hozzáadása",
    "Import" : "Import",
    "Export" : "Exportálás",
    "Sorting" : "Rendezés",
    "Recently added" : "Utoljára hozzáadva",
    "Alphabetically" : "Betűrendben",
    "Most visited" : "Legtöbbet látogatva",
    "Last modified" : "Utoljára módosítva",
    "Client apps" : "Kliensalkalmazások",
    "Bookmarklet" : "Bookmarklet",
    "Add to {instanceName}" : "Hozzáadás ehhez: {instanceName}",
    "Clear data" : "Adatok törlése",
    "Delete all bookmarks" : "Összes könyvjelzők törlése",
    "Do you really want to delete all your bookmarks?" : "Biztos, hogy törli az összes könyvjelzőt?",
    "Title" : "Cím",
    "Link" : "Hivatkozás",
    "Creation date" : "Létrehozás dátuma",
    "Tags" : "Cimkék",
    "Attachments" : "Mellékletek",
    "Notes" : "Jegyzetek",
    "Owner" : "Tulajdonos",
    "Sharing" : "Megosztás",
    "Share link" : "Hivatkozás megosztása",
    "Copy link" : "Hivatkozás másolása",
    "Allow editing" : "Szerkesztés engedélyezése",
    "Remove share" : "Megosztás eltávolítása",
    "Link copied" : "Hivatkozás másolva",
    "Select" : "Kijelölés",
    "Previews" : "Előnézetek",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Ingyenesen regisztrálhat a screeenly.com weboldalon, vagy beállíthatja a saját kiszolgálóját.",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API-kulcs",
    "Privacy" : "Adatvédelem",
    "Performance" : "Teljesítmény",
    "Failed to load settings" : "A beállítások betöltése sikertelen",
    "Failed to save settings" : "A beállítások mentése sikertelen",
    "This URL is already bookmarked! Overwrite?" : "Ez a cím már jegyezve van. Felülírod?",
    "Enter bookmark title" : "Adja meg a könyvjelző címét",
    "Enter bookmark URL" : "Adja meg a könyvjelző URL-ét",
    "Folder" : "Mappa",
    "Save" : "Mentés",
    "Failed to find existing bookmark" : "A létező könyvjelző keresése sikertelen",
    "Failed to create bookmark" : "Könyvjelző létrehozása sikertelen",
    "Failed to save bookmark" : "Könyvjelző mentése sikertelen",
    "Failed to move bookmark" : "Könyvjelző áthelyezése sikertelen",
    "Failed to delete bookmark" : "Könyvjelző törlése sikertelen",
    "Failed to load tags" : "Könyvjelző címkéinek betöltése sikertelen",
    "Failed to load folders" : "Mappák betöltése sikertelen",
    "Failed to delete folder" : "Mappa törlése sikertelen",
    "Failed to create folder" : "Mappa létrehozása sikertelen",
    "Failed to fetch bookmarks." : "Könyvjelzők lekérése sikertelen.",
    "Failed to change setting" : "Beállítások módosítása sikertelen",
    "Bookmarks feed" : "Könyvjelzők folyam"
},
"nplurals=2; plural=(n != 1);");
